import Gio from 'gi://Gio';
import Gtk from 'gi://Gtk';
import Adw from 'gi://Adw';

import {ExtensionPreferences} from 'resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js';


export default class DashBarExtensionPreferences extends ExtensionPreferences {
    fillPreferencesWindow(window) {
        window._settings = this.getSettings();

        const page = new Adw.PreferencesPage({
            title: 'DashBar task bar',
            icon_name: 'dialog-information-symbolic',
        });
        window.add(page);

        const group1 = new Adw.PreferencesGroup({
            title: 'Items and tasks',
        });
        page.add(group1);

        const row_show_appgrid = new Adw.SwitchRow({
            title: 'Show app grid',
        });
        group1.add(row_show_appgrid);
        window._settings.bind('show-appgrid', row_show_appgrid, 'active', Gio.SettingsBindFlags.DEFAULT);

        const row_show_only_running_apps = new Adw.SwitchRow({
            title: 'Show only running apps',
        });
        group1.add(row_show_only_running_apps);
        window._settings.bind('show-only-running-apps', row_show_only_running_apps, 'active', Gio.SettingsBindFlags.DEFAULT);

        const row_show_only_active_workspace_apps = new Adw.SwitchRow({
            title: 'Show only apps in active workspace',
        });
        group1.add(row_show_only_active_workspace_apps);
        window._settings.bind('show-only-active-workspace-apps', row_show_only_active_workspace_apps, 'active', Gio.SettingsBindFlags.DEFAULT);

        const group2 = new Adw.PreferencesGroup({
            title: 'Settings',
        });
        page.add(group2);

        const adjustment = new Gtk.Adjustment({
            lower: 8,
            upper: 26,
            step_increment: 1,
        });

        const row_icon_size = new Adw.SpinRow({
            title: 'Icon size',
            adjustment,
        });
        group2.add(row_icon_size);
        window._settings.bind('icon-size', row_icon_size, 'value', Gio.SettingsBindFlags.DEFAULT);
    }
}
